// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "UILabelNew.hpp"
#include "game/DawnGame.hpp"

using namespace Dawn;

UILabelNew::UILabelNew(SceneItem *item) : UIComponentRenderable(item) {

}

void UILabelNew::onStart() {
  std::cout << "Hello new Label" << std::endl;

  this->shaderBuffer.init();

  struct FontShaderBufferData fontData;

  int32_t n = 4 * 4;
  this->mesh.createBuffers(n * QUAD_VERTICE_COUNT, n * QUAD_INDICE_COUNT);
  for(int32_t i = 0; i < n; i++) {
    glm::vec2 size = glm::vec2(32, 32);
    glm::vec2 pos = glm::vec2(size.x * i, 0) + glm::vec2(2 * i, 0);
    QuadMesh::bufferQuadMeshWithZ(&this->mesh,
      pos, glm::vec2(0, 0),
      pos + size, glm::vec2(1, 1),
      0.0f, i * QUAD_VERTICE_COUNT, i * QUAD_INDICE_COUNT
    );
    fontData.fontQuadParts[i] = i / 4;
  }

  fontData.fontParts[0].color = COLOR_RED;
  fontData.fontParts[1].color = COLOR_GREEN;
  fontData.fontParts[2].color = COLOR_BLUE;
  fontData.fontParts[3].color = COLOR_MAGENTA;
  fontData.fontParts[4].color = COLOR_BLACK;
  fontData.fontParts[5].color = COLOR_WHITE;

  shaderBuffer.buffer(&fontData);
}

std::vector<struct ShaderPassItem> UILabelNew::getUIRenderPasses() {
  auto canvas = this->getCanvas();
  auto shader = getGame()->renderManager.fontShader;

  struct ShaderPassItem item;
  item.shader = shader;
  item.mesh = &mesh;
  item.matrixValues[shader->paramModel] = transform->getWorldTransform();
  item.parameterBuffers[shader->bufferUiCanvas] = &canvas->shaderBuffer;
  item.parameterBuffers[shader->bufferFont] = &this->shaderBuffer;

  return { item };
}


float_t UILabelNew::getWidth() {
  return 0;
}

float_t UILabelNew::getHeight() {
  return 0;
}

float_t UILabelNew::getContentWidth() {
  return 0;
}

float_t UILabelNew::getContentHeight() {
  return 0;
}